@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base qw(DateTime::Format::Natural::Compat);
 
-our $VERSION = '1.27';
+our $VERSION = '1.29';
 
 use constant MORNING   => '08';
 use constant AFTERNOON => '14';
@@ -364,11 +364,13 @@ sub _day_month_year
     $self->_register_trace;
     my $opts = pop;
     my ($day, $month, $year) = @_;
-    $self->_set(
-        year  => $year,
-        month => $month,
-        day   => $day,
-    );
+    if ($self->_valid_date(year => $year, month => $month, day => $day)) {
+        $self->_set(
+            year  => $year,
+            month => $month,
+            day   => $day,
+        );
+    }
 }
 
 sub _count_weekday_from_now
@@ -457,6 +459,6 @@ Steven Schubiger <schubiger@cpan.org>
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
-See L<http://www.perl.com/perl/misc/Artistic.html>
+See L<http://dev.perl.org/licenses/>
 
 =cut
